@@ -81,4 +81,31 @@ def ReadCache(name=str, src=any, rm=bool):
 
         return b
 
-#0.0.6
\ No newline at end of file
+def DelCache(src=any):
+    """
+    Delete file
+
+    src = File location; example: "foo/bar.txt"
+    """
+
+    import os
+    from os.path import exists
+
+    a = os.path.exists(f"{src}")
+
+    if a == True:
+
+        os.remove(f"{src}")
+        del os
+        del exists
+
+        return 1
+
+    if a == False:
+
+        print(f"{src} not found")
+        del os
+        del exists
+        return 0
+
+#0.0.7
\ No newline at end of file
